@@ -1,6 +1,6 @@
 #############################################################################
 #
-# $Id: gis_set.tcl,v 1.11 2005/01/20 13:13:10 markus Exp $
+# $Id: gis_set.tcl,v 1.11.2.1 2005/04/09 05:58:41 markus Exp $
 #
 # MODULE:   	Grass Tcl/Tk Initialization
 # AUTHOR(S):	Original author unknown - probably CERL
@@ -33,7 +33,7 @@ set GRASSVERSION [read -nonewline $fp]
 close $fp
 
 #HTML help
-source $env(GISBASE)/docs/nviz/help.tcl
+source $env(GISBASE)/etc/help.tcl
 proc make_help_window { w } {
 
         frame $w
